class Element:
    def data(self):
        print(f"Name: {self.name}\nChemical Symbol: {self.chemical_symbol}\nAtomic Mass: {self.atomic_mass}\nAtomic Number: {self.atomic_number}\ntype: {self.type}")


class Hydrogen(Element):
    name = "Hydrogen"
    chemical_symbol = "H"
    atomic_mass = 1.0079
    atomic_number = 1
    type = "Reactive Metals"

class Helium(Element):
    name = "Helium"
    chemical_symbol = "He"
    atomic_mass = 4.0026
    atomic_number = 2
    type = "Mainly Non-metals"

class Lithium(Element):
    name = "Lithium"
    chemical_symbol = "Li"
    atomic_mass = 6.941
    atomic_number = 3
    type = "Reactive Metals"

class Beryllium(Element):
    name = "Beryllium"
    chemical_symbol = "Be"
    atomic_mass = 9.0122
    atomic_number = 4
    type = "Reactive Metals"


def _print_list(list):
    num = 1
    if len(list) != 0:
        print("\nYour list:")
        for l in list:
            if num >= len(list):
                print("    " + str(num) + ") " + l + "\n")
            else:
                print("    " + str(num) + ") " + l)
            num += 1
    else:
        print("\nYour list is empty.\n")


def shopping_list():
    userList = []
    userInput = input("Enter your item: ")

    while userInput.lower() != "done":
        if userInput.lower() == "showlist":
            _print_list(userList)
        elif userInput.lower().startswith("remove"):
            remove = userInput.lower().replace("remove", "").strip()
            if remove != "*":
                userList.remove(remove)
            else:
                userList = []
        else:
            userList.append(userInput)
        userInput = input("Enter your item: ")
    _print_list(userList)
    saveFile = input("Save file to txt? (y/n) ")
    num = 1
    fileWrite = ""
    if len(userList) != 0:
        fileWrite += "Your list:\n"
        for l in userList:
            if num <= len(userList):
                fileWrite += "    " + str(num) + ") " + str(l) + "\n"
            else:
                fileWrite += "    " + str(num) + ") " + str(l)
            num += 1
    else:
        fileWrite += "\nYour list is empty.\n"

    if saveFile == "y":
        filePath = str(input("File path: ").replace("\\", "\\\\"))
        with open(filePath + "\\Your_List.txt", "w") as file:
            file.write(fileWrite)
            file.close()
    else:
        return